#
# spec file for package nmon
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2011-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nmon
Version:        16q
Release:        1.1
Summary:        Performance Monitor
License:        GPL-3.0-only
URL:            https://nmon.sourceforge.io/pmwiki.php
Source0:        https://sourceforge.net/projects/nmon/files/lmon%{version}.c
Source1:        https://www.gnu.org/licenses/gpl-3.0.txt
BuildRequires:  ncurses-devel
Provides:       lmon = %{version}

%description
This systems administrator, tuner, benchmark tool gives you a huge amount of
important performance information in one go. It can output the data in two ways

1. On screen (console, telnet, VNC, putty or X Windows) using curses for low
   CPU impact which is updated once every two seconds. You hit single characters
   on you keyboard to enable/disable the various sorts of data.
   * You can display the CPU, memory, network, disks (mini graphs or numbers),
     file systems, NFS, top processes, resources (Linux version & processors)
     and on Power micro-partition information.
2. Save the data to a comma separated file for analysis and longer term data
   capture.
   * Use this together with nmon Analyser Excel 2000 spreadsheet, which loads
     the nmon output file and automatically creates dozens of graphs ready for
     you to study or write performance reports.
   * Filter this data, add it to a rrd database (using an excellent freely
     available utility called rrdtool). This graphs the data to .gif or .png
     files plus generates the webpage .html file and you can then put the
     graphs directly on a website automatically on AIX with no need of a
     Windows based machine.
   * Directly put the data into a rrd database or other database for your own
     analysis

%prep
%setup -q -T -c %{name}-%{version}

%build
export CFLAGS="%{optflags} \
  -fPIE \
  -D JFS \
  -D GETUSER \
  -D LARGEMEM \
  -D KERNEL_2_6_18 \
  %if !0%{?is_opensuse}
  -D SLES12 \
  %endif
  %{SOURCE0}"
export LDFLAGS="-o nmon \
  -lncurses \
  -lm \
  -Wl,--as-needed \
  -Wl,--no-undefined \
  -Wl,-z,relro,-z,now \
  -pie"
%ifarch ppc ppc64 ppc64le
cc $CFLAGS -D PPC \
  $LDFLAGS
%endif
%ifarch s390x
cc $CFLAGS -D MAINFRAME \
  $LDFLAGS
%endif
%ifarch %{arm} aarch64
cc $CFLAGS -D ARM \
  $LDFLAGS
%endif
%ifarch %{ix86} x86_64
cc $CFLAGS -D X86 \
  $LDFLAGS
%endif

%install
install -Dpm 0755 nmon \
  %{buildroot}%{_bindir}/nmon
ln -s nmon %{buildroot}%{_bindir}/lmon
cp %{SOURCE1} LICENSE.GPL-3.0

%files
%license LICENSE.GPL-3.0
%{_bindir}/nmon
%{_bindir}/lmon

%changelog
* Sat Feb  8 2025 Dirk Müller <dmueller@suse.com>
- update to 16q:
  * bugfixes
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 16p:
  * Small improvements to on-screen use only :
    + CLI -B and GUI 'B' to toggle boxes around stats.
    + CLI -^ and '^' to change units for Disk I/O KB/s -> MB/s -> GB/s.
    This happen temporarily too if the size of the statistic
    will not fit on-scree.
  * Code changed to ensure clean compile for GCC 12
* Sun Apr 10 2022 Dirk Müller <dmueller@suse.com>
- update to 16n:
  * 0 maximum CPUs for the Power10 E1080 (needed for massive Linux running SAP
    HAMA servers) and small fixes
* Tue Nov 12 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 16m:
  * Fix only effect POWER LPARs in the rarely used (IMHO) Dedicated
    Donating mode, which is actually more like Shared CPU than
    Dedicated so Shared CPU LPAR stats are now switched on. This is
    the mode choosen for most SAP HANA workloads on POWER. Does not
    effect AMD64 or other platforms.
* Sat May 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 16j:
  * Newer Linux kernels do not have the SharedMem statistic so it
    reported instead the Shmem statsitic - this is the same shared
    memory number but includes RAM disk
  * Disk service times captured to file: Calculation corrections for
    Disk Group DGREADSERV & DGWRITESERV (missing device by elapsed time)
  * Disk DGIOTIME captured to file: removed (duplicate of DGBUSY as
    the millisecond doing IOTOME are used to calculate %%busy for Disk
    Groups this is the percent time of all disks in the group)
  * POWER partition stats on screen label (Memory Desired fixed)
  * LARGEMEM removed and SMALLMEM only for very old Linux
  * GETUSER and JFS removed
  * KERNEL_2_6_18 for new kernels changed to PRE_KERNEL_2_6_18 only
    for older kernels
- Update to version 16i:
  * If using the -F option there was rare chance the filename gets a
    few random characters at the end.
  * From Linux kernel 2.8.19 onwards nr_slab was removed and
    nr_slab_reclaimable & nr_slab_unreclaimable added.
  * Online MHz stats (M) on small VM still took up 20 lines. Now
    reduced in size.
* Thu Jan 10 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 16h:
  * Internal code changes for robustness malloc() and
    snprintf/strncpy.
  * POWER pool_capacity now correctly divided by 100.
  * Online view ARM lscpu command column format depends on your
    hardware
  * Online view ALL /proc/cpuinfo format depends on your hardware
    and new lines - like MMU: Hash or MMU:
  * Online view POWER Welcome panel on POWER reports the top MHz
- Drop manpage generation
* Wed Apr 18 2018 aloisio@gmx.com
- Update to version 16g
  Small changes only:
  * Now cope with 192 physical CPU cores with SMT=8 (for POWER8
    servers)
  * Fixed bug reported with NFS automount in data capture mode
    + Alternatively, completely switch off JFS stats in capture
    mode with "-J"
  * Online view: remove File systems that are "not real" to
    reduce screen space. Hit "j" and then "J" to remove the
    pointless file systems
  * Online view: Small clean up of the titles for the Memory
    stats (m)
* Fri Jul  8 2016 mpluskal@suse.com
- Simplify build process a bit
- Build as PIE
* Sat Jun 18 2016 mpluskal@suse.com
- Update to version 16f (boo#985538):
  * Minor changed to the on-screen view only.
* Fri Apr  8 2016 mpluskal@suse.com
- Update to 16e (boo#974718)
  * Boottime shown online in the Kernel "k" panel
  * Utilisation stats: /proc/stat now reports 10 Utilisation stats
    including KVM guest VM CPU use = cool.
  * Bug caused Seg Faults core dumps fixed while collecting to a
    file including top process stats.
  * Fix: Improved memory handling for extreme numbers of processes
    (1000's) or rapid exec of processes  (100's in a millisecond)
    for large Linux servers. We have examples on Intel of 80 CPU
    cores and POWER 160+
  * Online Dot "." command no longer also changes what is displayed
    as users said it was confusing.
  * Minor online start-up flash screen text changes to include C
    concise CPU stats and U for full  Utilisation stats (all 10 of
    them) instead of a file.
  * Copyright and GPL v3 notice in the code plus online "h" and
    nmon -h output
- Improve manpage generation
* Fri Mar 18 2016 mpluskal@suse.com
- Enable all features for non intel architectures
- Enable support for modern kernels
- Add symlink to lmon manpage
* Sat Mar 12 2016 mpluskal@suse.com
- Update to 16d
  * Source code re-indented.
  * Fixes for Welcome screen on Mainframe
  * Fixed for Curses handling when collecting data to file - big
    bug for main frame and x86.
- Changes for 16b
  * Fixes for Welcome screen on Mainframe
  * Fixed for Curses handling when collecting data to file - big
    bug for main frame and x86.
- Changes for 16a
  * Nvidia GPU support - online & saved to file
    + You need a S822LC With NVIDIA GPU(s) and Nvidia Library
    installed libnvidia-ml.so
  * CPU Wide View - online view for up to 192 CPUs
  * CPU MHz per Core ratings for machine that allow cores with
    different MHz - online & saved to file
  * lscpu stats capture - online & to file
  * Z experiment mode showing CPU interrupts - Renamed U stats in
    version 16b - online only
  * Online colourising stats to aid usability - online only
  * Massive improvement in help information: nmon -? and nmon -h
  * Code change to alphabetic order for getopt() and key input
    functions - just code clean up
  * New nmon logo on flash screen - online only
  * Extra kernel stats - online only
- Drop nmon.1 and genereate manpage during build
* Sun Dec 13 2015 mpluskal@suse.com
- Update to 15h
  * No upstream changelog available
- Cleanup spec file
* Sun Aug  2 2015 mpluskal@suse.com
- Update to 15g
  * No upstream changelog available
* Fri Mar  6 2015 p.drouand@gmail.com
- Update to version 15a
  * Original PowerVM host environment supported
  * PowerKVM host environment supported
  /proc/ppc64/lparcfg is missing and SMT is switched off even
    is guests have it one
  * PowerKVM guest environment supported
  /proc/ppc64/lparcfg - probably mostly missing (1.9)
  * Native guest environment supported - not virtualised
  * Support Big and Little Endian - for POWER machines that can run both
- Do not re-tar the source file; not really useful
- Use download Url as source
* Tue Oct 28 2014 mpluskal@suse.com
- Add manpage
- Add licence file
- Minor spec file cleanup
* Fri Oct  4 2013 malcolmlewis@opensuse.org
- Updated to version 14i:
  + 2nd attempt at fixing my NFS stats bug - thanks to helpful
    users.
  + Dynamic memory handling for massive /proc/cpuinfo file & so
    much duplication & Tabs chars plus many formats on x86.
  + POWER has new LPAR details on the CPU stats online,
    Entitlement, Physical CPU used, Capped, SMT level, virtual
    Processors and Dotted lines on each primary thread helps you
    "see" the physical CPUs, plus file output saves the above,
    lparstat -i, ppc64_cpu & lsslot, ls-veth/vdev/vscsi, lscfg &
    bootlist commands output, saves SMT on the LPAR tab last
    column.
  + Start up flash panel has X86 or POWER CPU details. Note: some
    x86 Virtual Machines report CPU type QEMU or Virtual CPU but
    many don't.
  + Add -D X86 in the makefile to get the new features.
- Updates from version 14h:
  + This included a fix for POWER based machines when the
    Entitlement CPU is set below 10%% of a CPU - only applies to
    the POWER7+ processors or POWER7 that has a firmware upgrade
    like Power 770/780/79 and a fix for a crash if you gather NFS
    serving stats on certain Linux distributions & versions.
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- initial version (14g)
